@@ -18,7 +18,6 @@ import sentry_sdk
 from asgi_correlation_id import CorrelationIdMiddleware
 from fastapi import FastAPI
 from fastapi.middleware.gzip import GZipMiddleware
-from opentelemetry.exporter.cloud_monitoring import CloudMonitoringMetricsExporter
 from opentelemetry.exporter.cloud_trace import CloudTraceSpanExporter
 from opentelemetry.sdk.metrics import MeterProvider
 from opentelemetry.sdk.metrics.export import PeriodicExportingMetricReader
@@ -29,10 +28,7 @@ from opentelemetry.sdk.trace.export import (
 from opentelemetry.sdk.trace.sampling import TraceIdRatioBased
 
 from superlinked.framework.common.parser.exception import MissingIdException
-from superlinked.framework.common.telemetry.telemetry_registry import (
-    MetricType,
-    TelemetryRegistry,
-)
+from superlinked.framework.common.telemetry.telemetry_registry import MetricType, telemetry
 from superlinked.framework.common.util.version_resolver import VersionResolver
 from superlinked.framework.online.dag.exception import ValueNotProvidedException
 from superlinked.server.configuration.settings import settings
@@ -45,6 +41,7 @@ from superlinked.server.logger import ServerLoggerConfigurator
 from superlinked.server.middleware.lifespan_event import lifespan
 from superlinked.server.middleware.timing_middleware import add_timing_middleware
 from superlinked.server.router.management_router import router as management_router
+from superlinked.server.util.retryable_cloud_exporter import RetryableCloudMonitoringMetricsExporter
 from superlinked.server.util.superlinked_app_downloader_util import download_from_gcs
 
 
@@ -60,7 +57,7 @@ class ServerApp:
         app.add_exception_handler(Exception, handle_generic_exception)
 
     def _create_app(self) -> FastAPI:
-        ServerLoggerConfigurator.setup_logger(settings)
+        ServerLoggerConfigurator.setup_logger()
         if settings.IS_DOCKERIZED:
             if not settings.BUCKET_NAME or not settings.BUCKET_PREFIX:
                 raise ValueError(
@@ -75,7 +72,7 @@ class ServerApp:
         self._setup_executor_handlers(app)
         app.include_router(management_router)
 
-        add_timing_middleware(app)
+        add_timing_middleware(app, debug_endpoints=["/health", "/version"])
         app.add_middleware(
             GZipMiddleware,
             minimum_size=settings.GZIP_MINIMUM_SIZE,
@@ -103,29 +100,33 @@ class ServerApp:
         if not settings.OPENTELEMETRY_PROJECT_ID:
             raise ValueError("OPENTELEMETRY_PROJECT_ID must be set in the environment variables")
 
-        telemetry_registry = TelemetryRegistry()
         framework_version = VersionResolver.get_version_for_package("superlinked") or "unknown"
         server_version = VersionResolver.get_version_for_package("superlinked-server") or "unknown"
         labels = {
-            "service": "superlinked-server",
+            "service": settings.OPENTELEMETRY_COMPONENT_NAME,
             "framework-version": framework_version,
             "version": server_version,
-            "environment": "DEV",
+            "environment": settings.ENVIORNMENT_NAME,
         }
-        telemetry_registry.add_labels(labels)
+        telemetry.add_labels(labels)
 
-        telemetry_registry.create_metric(MetricType.COUNTER, "http_requests_total", "Count of HTTP requests", "1")
-        telemetry_registry.create_metric(
+        telemetry.create_metric(MetricType.COUNTER, "http_requests_total", "Count of HTTP requests", "1")
+        telemetry.create_metric(
             MetricType.HISTOGRAM, "http_request_duration_ms", "HTTP request duration in milliseconds", "ms"
         )
-        telemetry_registry.create_metric(
+        telemetry.create_metric(
             MetricType.COUNTER,
             "ingested_items_with_data_loader_total",
             "Count of ingested items with data loader",
             "item",
         )
 
-        metric_exporter = CloudMonitoringMetricsExporter(settings.OPENTELEMETRY_PROJECT_ID, add_unique_identifier=True)
+        metric_exporter = RetryableCloudMonitoringMetricsExporter(
+            settings.OPENTELEMETRY_PROJECT_ID,
+            add_unique_identifier=True,
+            max_attempts=settings.OPENTELEMETRY_RETRY_MAX_ATTEMPTS,
+        )
+
         metric_reader = PeriodicExportingMetricReader(
             exporter=metric_exporter, export_interval_millis=settings.OPENTELEMETRY_EXPORT_INTERVAL_IN_MS
         )
@@ -136,7 +137,7 @@ class ServerApp:
         tracer_provider = TracerProvider(sampler=TraceIdRatioBased(settings.OPENTELEMETRY_TRACE_SAMPLING_RATE))
         tracer_provider.add_span_processor(BatchSpanProcessor(cloud_trace_exporter))
 
-        telemetry_registry.initialize(
+        telemetry.initialize(
             MeterProvider(metric_readers=[metric_reader]),
             tracer_provider=tracer_provider,
             component_name=settings.OPENTELEMETRY_COMPONENT_NAME,
