@@ -18,7 +18,7 @@ from fastapi import Request, Response, status
 from fastapi.responses import JSONResponse
 from pydantic import Field
 
-from superlinked.framework.common.telemetry.telemetry_registry import TelemetryRegistry
+from superlinked.framework.common.telemetry.telemetry_registry import telemetry
 from superlinked.framework.common.util.immutable_model import ImmutableBaseModel
 from superlinked.framework.dsl.executor.rest.rest_handler import RestHandler
 from superlinked.framework.dsl.query.query_user_config import QueryUserConfig
@@ -39,11 +39,10 @@ class QueryResponse(ImmutableBaseModel):
 class FastApiHandler:
     def __init__(self, rest_handler: RestHandler) -> None:
         self.__rest_handler = rest_handler
-        self.__telemetry = TelemetryRegistry()
 
     async def ingest(self, request: Request) -> Response:
         payload = await request.json()
-        with self.__telemetry.span("api_handler.query", attributes={"path": request.url.path}):
+        with telemetry.span("api_handler.ingest", attributes={"path": request.url.path}):
             self.__rest_handler._ingest_handler(payload, request.url.path)
         logger.debug("ingested data", path=request.url.path, pii_payload=payload)
         return Response(status_code=status.HTTP_202_ACCEPTED)
@@ -52,7 +51,7 @@ class FastApiHandler:
         payload = await request.json()
         query_user_config = self.calculate_query_user_config(request)
         labels = {"path": request.url.path, "include_metadata": query_user_config.with_metadata}
-        with self.__telemetry.span("api_handler.query", attributes=labels):
+        with telemetry.span("api_handler.query", attributes=labels):
             query_result = await self.__rest_handler._query_handler(payload, request.url.path, query_user_config)
         logger.debug(
             "queried data",
@@ -64,9 +63,9 @@ class FastApiHandler:
             pii_payload=payload,
             pii_result=query_result,
         )
-        exclude_dict = {} if query_user_config.with_metadata else {"metadata"}
+        exclude_set = set() if query_user_config.with_metadata else {"metadata"}
         return JSONResponse(
-            content=query_result.model_dump(exclude=exclude_dict),
+            content=query_result.model_dump(exclude=exclude_set),
             status_code=status.HTTP_200_OK,
         )
 
